@@ -20,6 +20,9 @@
 #' of infrastructure networks}. Physical Review E, 71:015103.
 
 vulnerability <- function(g, .parallel=TRUE, weighted=FALSE) {
+  if (!is.igraph(g)) {
+    stop(sprintf('%s is not a graph object', deparse(substitute(g))))
+  }
   if (isTRUE(weighted)) {
     weights <- NULL
     g.attr <- 'E.global.wt'
